@@ -1,5 +1,7 @@
 from aws.region import get_secret
 import json
+import time
+
 
 def get_secret_value(name: str, key: str = None):
   """
@@ -21,6 +23,7 @@ def get_secret_value(name: str, key: str = None):
   else:
     return response.get('SecretBinary')
 
+
 def create_secret(name: str, description: str = "", binary: bytes = None, string: str = None, kvp: dict = None, tags: dict = None):
   """
   Creates a secret with either a binary or string/json value. You cannot supply both a binary and string value, but you must supploy one.
@@ -65,6 +68,7 @@ def create_secret(name: str, description: str = "", binary: bytes = None, string
     r['Tags'] = formatted_tags_list
   return r
 
+
 def update_secret(name: str, binary = None, string: str = None, kvp: dict = None, overwriteJson: bool = False):
   """
   Updates a secret. If you supply a binary or string, that becomes the new value of the secret. If you supply a dict, that dict's values
@@ -88,19 +92,21 @@ def update_secret(name: str, binary = None, string: str = None, kvp: dict = None
     use_json = False
   if use_json:
     if overwriteJson:
-      r = get_secret().update_secret(SecretId = name, SecretString = json.dumps(kvp))
-      r['SecretString'] = json.dumps(kvp)
+      secret_string = json.dumps(kvp)
+      r = get_secret().update_secret(SecretId = name, SecretString = secret_string)
+      r['SecretString'] = wait_for_secret(name, value=secret_string)
     else:
       for k in kvp:
         existing_json[k] = kvp[k]
-      r = get_secret().update_secret(SecretId = name, SecretString = json.dumps(existing_json))
-      r['SecretString'] = json.dumps(existing_json)
+      secret_string = json.dumps(existing_json)
+      r = get_secret().update_secret(SecretId = name, SecretString = secret_string)
+      r['SecretString'] = wait_for_secret(name, value=secret_string)
   elif type(existing) is str:
     r = get_secret().update_secret(SecretId = name, SecretString = string)
-    r['SecretString'] = string
+    r['SecretString'] = wait_for_secret(name, value=string)
   else: # binary
     r = get_secret().update_secret(SecretId = name, SecretBinary = binary)
-    r['SecretBinary'] = binary
+    r['SecretBinary'] = wait_for_secret(name, value=binary)
   return r
 
 
@@ -125,4 +131,22 @@ def delete_secret(name: str, recovery_window: int = None, perma_delete: bool = F
       get_secret().delete_secret(SecretId = name, RecoveryWindowInDays = recovery_window)
   except:
     return False # the secret doesn't exist
-  return recovery_window
\ No newline at end of file
+  return recovery_window
+
+
+def wait_for_secret(name: str, value = None, timeout: int = 60):
+  """
+  Wait for a secret to have the given value.
+  This is useful for synchronization purposes, as updates to secrets are not always immediately reflected in subsequent requests.
+
+  :param name: The name of the secret to wait on.
+  :param value: The value to wait for. If None, will wait for secret to be deleted.
+  :param timeout: The maximum time to wait, after which an Exception will be thrown. Default is 60 seconds.
+  :return: The secret value, once it matches
+  """
+  for i in range(timeout):
+    found = get_secret_value(name)
+    if found == value:
+      return found
+    time.sleep(1)
+  raise TimeoutError('Secret did not change to the expected value')
\ No newline at end of file
