@@ -7,6 +7,7 @@ from os import path
 
 VPC_NAME = test_cluster.CONFIG.vpc_name
 
+HOSTED_ZONE_STACK = None
 VPC_STACK = None
 VPC = None
 VPC_ID = None
@@ -25,13 +26,18 @@ class TestEC2(unittest.TestCase):
         # Hide boto3 warnings. This is a known issue with boto3 + unittest.
         warnings.simplefilter('ignore', category=ResourceWarning)
 
-        global VPC_STACK, VPC, VPC_ID, KP
+        global VPC_STACK, VPC, VPC_ID, KP, HOSTED_ZONE_STACK
 
         vpc = cluster.get_vpc(VPC_NAME)
         cp = cluster.get_cp(VPC_NAME)
         workers = cluster.get_eks_workers(VPC_NAME)
         if not vpc or not cp or not workers:
             raise RuntimeError('must call test_cluster.create_test_cluster() prior to this test')
+
+        HOSTED_ZONE_STACK = cfm.create_stack(
+            _abs_path('templates/hosted-zone.yaml'),
+            stack_name='unit-hosted-zone',
+            params={'VpcId': cfm.get_output(vpc, 'VPC')})
         
         VPC_STACK = vpc
         VPC_ID = cfm.get_output(VPC_STACK, 'VPC')
@@ -44,6 +50,7 @@ class TestEC2(unittest.TestCase):
 
     @classmethod
     def tearDownClass(cls):
+        cfm.delete_stack(HOSTED_ZONE_STACK['StackName'])
         region.get_ec2().delete_key_pair(KeyName=KP.get('KeyName'))
 
 
@@ -484,15 +491,16 @@ class TestEC2(unittest.TestCase):
     ###########################################################################
 
     def test_list_hosted_zones(self):
-        zones = ec2.list_hosted_zones()
-        self.assertNotEqual(zones, [])
+        expected_zones = region.get_route53().list_hosted_zones().get('HostedZones', [])
+        returned_zones = ec2.list_hosted_zones()
+        self.assertNotEqual(returned_zones, [])
+        self.assertEqual(returned_zones, expected_zones)
 
 
     def test_get_zone_vpc_ids(self):
-        zone_id = ec2.list_hosted_zones()[0].get('Id')
+        zone_id = cfm.get_output(HOSTED_ZONE_STACK, 'HostedZone')
         vpc_ids = ec2.get_zone_vpc_ids(zone_id)
-        self.assertNotEqual(vpc_ids, [])
-
+        self.assertIn(VPC_ID, vpc_ids)
 
 
 if __name__ == "__main__":
