@@ -98,26 +98,27 @@ class TestSecret(unittest.TestCase):
     ###########################################################################
 
     def test_create_secret_with_tags(self):
-        string_secret = secret.create_secret(
-            name='unit-test-string-secret-with-tags',
-            string='string-secret',
-            tags={'type': 'string'})['Name']
+        try:
+            string_secret = secret.create_secret(
+                name='unit-test-string-secret-with-tags',
+                string='string-secret',
+                tags={'type': 'string'})['Name']
 
-        binary_secret = secret.create_secret(
-            name='unit-test-binary-secret-with-tags',
-            binary=b'binary-secret',
-            tags={'type': 'binary'})['Name']
+            binary_secret = secret.create_secret(
+                name='unit-test-binary-secret-with-tags',
+                binary=b'binary-secret',
+                tags={'type': 'binary'})['Name']
 
-        tag_found = lambda tags, k, v: any(pair for pair in tags if pair['Key'] == k and pair['Value'] == v)
+            tag_found = lambda tags, k, v: any(pair for pair in tags if pair['Key'] == k and pair['Value'] == v)
 
-        string_secret_tags = region.get_secret().describe_secret(SecretId=string_secret)['Tags']
-        self.assertTrue(tag_found(string_secret_tags, 'type', 'string'))
+            string_secret_tags = region.get_secret().describe_secret(SecretId=string_secret)['Tags']
+            self.assertTrue(tag_found(string_secret_tags, 'type', 'string'))
 
-        binary_secret_tags = region.get_secret().describe_secret(SecretId=binary_secret)['Tags']
-        self.assertTrue(tag_found(binary_secret_tags, 'type', 'binary'))
-
-        secret.delete_secret(string_secret, perma_delete=True)
-        secret.delete_secret(binary_secret, perma_delete=True)
+            binary_secret_tags = region.get_secret().describe_secret(SecretId=binary_secret)['Tags']
+            self.assertTrue(tag_found(binary_secret_tags, 'type', 'binary'))
+        finally:
+            secret.delete_secret(string_secret, perma_delete=True)
+            secret.delete_secret(binary_secret, perma_delete=True)
 
 
     def test_create_secret_multiple_types(self):
@@ -177,19 +178,29 @@ class TestSecret(unittest.TestCase):
 
 
     def test_delete_secret_with_recovery(self):
-        string_secret = secret.create_secret(
-            name='unit-test-string-secret-delete-with-recovery',
-            string='string-secret')['Name']
+        try:
+            string_secret = secret.create_secret(
+                name='unit-test-string-secret-delete-with-recovery',
+                string='string-secret')['Name']
 
-        secret.delete_secret(string_secret)
-        found = secret.get_secret_value(string_secret)
-        self.assertIsNone(found)
+            secret.delete_secret(string_secret)
+            found = secret.get_secret_value(string_secret)
+            self.assertIsNone(found)
 
-        region.get_secret().restore_secret(SecretId=string_secret)
-        found = secret.get_secret_value(string_secret)
-        self.assertIsNotNone(found)
+            region.get_secret().restore_secret(SecretId=string_secret)
+            found = secret.get_secret_value(string_secret)
+            self.assertIsNotNone(found)
+        finally:
+            secret.delete_secret(string_secret, perma_delete=True)
 
-        secret.delete_secret(string_secret, perma_delete=True)
+
+    ###########################################################################
+    # Wait for Secret
+    ###########################################################################
+
+    def test_wait_for_secret_timeout(self):
+        with self.assertRaises(TimeoutError):
+            secret.wait_for_secret(self.STRING_SECRET['Name'], 'bogus', timeout=3)
 
 
 if __name__ == "__main__":
